==> monodevelop_0.12+dfsg.orig.tar.gz: monodevelop-0.12+dfsg.orig/Extras/MonoDevelop.GtkCore/MonoDevelop.GtkCore.NodeBuilders/WindowsFolder.cs <==
//
// WindowsFolder.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Projects;
using MonoDevelop.GtkCore.GuiBuilder;

namespace MonoDevelop.GtkCore.NodeBuilders
{
	class WindowsFolder
	{
		Project project;
		
		public event EventHandler Changed;
		
		public WindowsFolder (Project project)
		{
			this.project = project;
			GtkDesignInfo info = GtkCoreService.GetGtkInfo (project);
			WindowEventHandler updateDelegate = new WindowEventHandler (OnUpdateFiles);
			info.GuiBuilderProject.WindowAdded += updateDelegate;
			info.GuiBuilderProject.WindowRemoved += updateDelegate;
			
			Stetic.Wrapper.ActionGroupEventHandler updateDelegate2 = new Stetic.Wrapper.ActionGroupEventHandler (OnUpdateFiles);
			info.GuiBuilderProject.SteticProject.ActionGroups.ActionGroupAdded += updateDelegate2;
			info.GuiBuilderProject.SteticProject.ActionGroups.ActionGroupRemoved += updateDelegate2;
		}
		
		public void Dispose ()
		{
			GtkDesignInfo info = GtkCoreService.GetGtkInfo (project);
			WindowEventHandler updateDelegate = new WindowEventHandler (OnUpdateFiles);
			info.GuiBuilderProject.WindowAdded -= updateDelegate;
			info.GuiBuilderProject.WindowRemoved -= updateDelegate;
			
			Stetic.Wrapper.ActionGroupEventHandler updateDelegate2 = new Stetic.Wrapper.ActionGroupEventHandler (OnUpdateFiles);
			info.GuiBuilderProject.SteticProject.ActionGroups.ActionGroupAdded -= updateDelegate2;
			info.GuiBuilderProject.SteticProject.ActionGroups.ActionGroupRemoved -= updateDelegate2;
		}
		
		void OnUpdateFiles (object s, WindowEventArgs args)
		{
			if (Changed != null) Changed (this, EventArgs.Empty);
		}
		
		void OnUpdateFiles (object s, Stetic.Wrapper.ActionGroupEventArgs args)
		{
			if (Changed != null) Changed (this, EventArgs.Empty);
		}
		
		public Project Project {
			get { return project; }
		}
	}
}

==> monodevelop_0.14+dfsg.orig.tar.gz: monodevelop-0.14/Extras/MonoDevelop.GtkCore/MonoDevelop.GtkCore.NodeBuilders/WindowsFolder.cs <==
//
// WindowsFolder.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Projects;
using MonoDevelop.GtkCore.GuiBuilder;

namespace MonoDevelop.GtkCore.NodeBuilders
{
	class WindowsFolder
	{
		Project project;
		
		public event EventHandler Changed;
		
		public WindowsFolder (Project project)
		{
			this.project = project;
			GtkDesignInfo info = GtkCoreService.GetGtkInfo (project);
			
			info.GuiBuilderProject.Changed += OnUpdateFiles;
		}
		
		public void Dispose ()
		{
			GtkDesignInfo info = GtkCoreService.GetGtkInfo (project);
			if (info != null)
				info.GuiBuilderProject.Changed -= OnUpdateFiles;
		}
		
		void OnUpdateFiles (object s, EventArgs args)
		{
			if (Changed != null) Changed (this, EventArgs.Empty);
		}
		
		public Project Project {
			get { return project; }
		}
	}
}
